==> calligra-2.7.5.tar.xz: calligra-2.7.5/libs/textlayout/tests/MockRootAreaProvider.h <==
/* This file is part of the KDE project
 * Copyright (C) 2011 C. Boemann <cbo@boemann.dk>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef MOCKROOTAREAPROVIDER_H
#define MOCKROOTAREAPROVIDER_H

#include "KoTextLayoutRootAreaProvider.h"

class MockRootAreaProvider : public KoTextLayoutRootAreaProvider
{
public:
    MockRootAreaProvider();

    /// reimplemented
    virtual KoTextLayoutRootArea *provide(KoTextDocumentLayout *documentLayout);
    virtual void releaseAllAfter(KoTextLayoutRootArea *afterThis);
    virtual void doPostLayout(KoTextLayoutRootArea *rootArea, bool isNewRootArea);
    virtual QSizeF suggestSize(KoTextLayoutRootArea *rootArea);
    virtual QList<KoTextLayoutObstruction *> relevantObstructions(KoTextLayoutRootArea *rootArea);
    virtual void updateAll();

    void setSuggestedSize(QSizeF size);

    KoTextLayoutRootArea *m_area;
    QSizeF m_suggestedSize;
    bool m_askedForMoreThenOneArea;
};

#endif

==> calligra_2.8.5.orig.tar.xz: calligra-2.8.5/libs/textlayout/tests/MockRootAreaProvider.h <==
/* This file is part of the KDE project
 * Copyright (C) 2011 C. Boemann <cbo@boemann.dk>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef MOCKROOTAREAPROVIDER_H
#define MOCKROOTAREAPROVIDER_H

#include "KoTextLayoutRootAreaProvider.h"

class MockRootAreaProvider : public KoTextLayoutRootAreaProvider
{
public:
    MockRootAreaProvider();

    /// reimplemented
    virtual KoTextLayoutRootArea *provide(KoTextDocumentLayout *documentLayout);
    virtual void releaseAllAfter(KoTextLayoutRootArea *afterThis);
    virtual void doPostLayout(KoTextLayoutRootArea *rootArea, bool isNewRootArea);
    virtual QRectF suggestRect(KoTextLayoutRootArea *rootArea);
    virtual QList<KoTextLayoutObstruction *> relevantObstructions(KoTextLayoutRootArea *rootArea);
    virtual void updateAll();

    void setSuggestedRect(QRectF rect);

    KoTextLayoutRootArea *m_area;
    QRectF m_suggestedRect;
    bool m_askedForMoreThenOneArea;
};

#endif
